# Skua
[![Deploy to Netlify](https://www.netlify.com/img/deploy/button.svg)](https://app.netlify.com/start/deploy?repository=https://github.com/teymour-aldridge/skua-starter-project)

**Documentation status**

[![Netlify Status](https://api.netlify.com/api/v1/badges/b9b885cc-1a28-4640-be7e-d37b7b56703b/deploy-status)](https://app.netlify.com/sites/skua/deploys)


### A pythonic static site generator.
[![Build Status](https://travis-ci.org/teymour-aldridge/skua.svg?branch=master)](https://travis-ci.org/teymour-aldridge/skua)
Skua is a static site generator designed to allow for more flexibility and extensibility than classic static site generators. 
### Documentation
Skua's documentation is build using [MkDocs](https://mkdocs.org) and is hosted at [skua.netlify.com](https://skua.netlify.com).
### Command-line interface
Skua can be used from the command line (still under development). It takes every template it finds and places an HTML template in the chosen output folder. 
### Python scripting
Skua can be imported and used to create Python scripts, which allows for greater flexibility and custom site generation pipelines. 
### Contributing
All contributions and contributors are welcome! If you're interested in contributing you should look at the 'boards' and 'wiki' tabs on our [Github page](https://github.com/teymour-aldridge/skua). 
### Versioning
Skua uses romantic versioning. We recommend not upgrading to a new version of Skua before you have read the description for the new release. 
* MAJOR: A conceptually major change with (possible) breaking changes.
* MINOR: A conceptually minor change with (possible) breaking changes
* PATCH: Guaranteed not to cause any breaking changes. Used for minor changes, such as:
    * Bug fixes in the current version
    * Updates to algorithms which don't add extra dependencies.